@@ -1,4 +1,5 @@
 // SPDX-FileCopyrightText: 2023 Devin Lin <devin@kde.org>
+// SPDX-FileCopyrightText: 2024 Luis Büchi <luis.buechi@kdemail.net>
 // SPDX-License-Identifier: GPL-2.0-or-later
 
 #pragma once
@@ -39,13 +40,16 @@ QMap<QString, QMap<QString, QVariant>> getKwinrcSettings(KSharedConfig::Ptr m_mo
 
     return {{"Windows",
              {
-                 {"Placement", convergenceModeEnabled ? "Centered" : "Maximizing"} // maximize all windows by default if we aren't in convergence mode
+                 {"Placement", convergenceModeEnabled ? "Centered" : "Maximizing"}, // maximize all windows by default if we aren't in convergence mode
+                 {"InteractiveWindowMoveEnabled", convergenceModeEnabled} // only allow window moving in convergence mode
              }},
             {"Plugins",
              {
                  {"blurEnabled", false}, // disable blur for performance reasons, we could reconsider in the future for more powerful devices
                  {"convergentwindowsEnabled", true}, // enable our convergent window plugin
-                 {"mobiletaskswitcherEnabled", true} // ensure the mobile task switcher plugin is enabled
+                 {"mobiletaskswitcherEnabled", true}, // ensure the mobile task switcher plugin is enabled
+                 {"screenedgeEnabled", false} // disable the blue highlighting of screen edge effects. TODO would be nice if we could only deactivate it on
+                                              // touchscreen gestures and not mouse as well
              }},
             {"Wayland",
              {
@@ -65,5 +69,8 @@ QMap<QString, QMap<QString, QVariant>> getKwinrcSettings(KSharedConfig::Ptr m_mo
 
 // Have a separate list here because we need to trigger DBus calls to load/unload each effect/script.
 // Make sure that the effect/script is added to the kwinrc "Plugins" section above!
-const QList<QString> KWIN_EFFECTS = {"blur", "mobiletaskswitcher"};
+const QList<QString> KWIN_EFFECTS = {"blur", "mobiletaskswitcher", "screenedge"};
 const QList<QString> KWIN_SCRIPTS = {"convergentwindows"};
+
+//ksmserver
+const QMap<QString, QMap<QString, QVariant>> KSMSERVER_SETTINGS = {{"General", {{"loginMode", "emptySession"}}}};
